#!/bin/bash
#
# Handle RPM installation and uninstallation, starting and stopping
# Pegasus as necessary.

RETVAL=0
PREFIX=$2

install_rpm() {
	# Start pegasus.
	if [ -f /etc/init.d/tog-pegasus  ] ; then
            /etc/init.d/tog-pegasus start &> /dev/null
            sleep 3
            /etc/init.d/tog-pegasus status &> /dev/null
	else
            systemctl start tog-pegasus.service &> /dev/null
            systemctl enable tog-pegasus.service &> /dev/null
            sleep 3
            systemctl status tog-pegasus.service &> /dev/null
        fi
        if [ $? != 0 ]; then
            echo "Failed to start tog-pegasus."
            return 1
        fi

        echo "Installing WBEM schema."
	# Install CIM schema in root/hpq namespace
	cimmof -uc -w -n root/hpq -I $PREFIX/mof/CIM2430 \
		$PREFIX/mof/CIM2430/cim_schema_2.43.0.mof

	# Install needed CIM schema in root/interop namespace
	cimmof -uc -w -n root/interop -I $PREFIX/mof/CIM2430 \
        $PREFIX/mof/cimv2430-coreinterop.mof
	
	# Install Qualifiers and SMX schema in root/hpq namespace
        cimmof -aE -uc -w -n root/hpq $PREFIX/mof/root/hpq/SMXQualifiers.mof
	
	for class in `cat $PREFIX/mof/moflist.root\#hpq`; do
		cimmof -aE -uc -w -n root/hpq -I $PREFIX/mof/root/hpq \
			$PREFIX/mof/root/hpq/$class.mof
	done
	
	# Install SMX schema in root/interop namespace
        cimmof -aE -uc -w -n root/interop $PREFIX/mof/root/hpq/SMXQualifiers.mof

	for class in `cat $PREFIX/mof/moflist.root\#interop`; do
		cimmof -uc -w -n root/interop -I $PREFIX/mof/root/interop \
	        	$PREFIX/mof/root/interop/$class.mof
	done	

	# Install SMX schema in root/cimv2 namespace
	for class in `cat $PREFIX/mof/moflist.root\#cimv2`; do
		cimmof -uc -w -n root/cimv2 -I $PREFIX/mof/root/cimv2 \
	        	$PREFIX/mof/root/cimv2/$class.mof
	done	

	
        echo "Installing SMX provider."
	# Run ldconfig to update our entry in /etc/ld.so.conf.d
	ldconfig

	# Register providers
	#tog-pegasus-2.12.1 ( RHEL7) replace "root/PG_InterOp" with "root/interop"
	if [ -f /etc/init.d/tog-pegasus  ] ; then
		cimmof -aE -uc -w -n root/PG_InterOp $PREFIX/reg/*R.mof
	else
		cimmof -aE -uc -w -n root/interop $PREFIX/reg/*R.mof
	fi
	
	# Create SMX_AutoStart indication subscription
	/opt/hp/hp-smx/bin/mkautostart

	if [ -d /opt/hp/hpshd ] ; then
		if [ -f /etc/init.d/hpshd  ] ; then
			/etc/init.d/hpshd stop &> /dev/null
			/etc/init.d/hpshd start &> /dev/null
		else
			systemctl stop hpshd &> /dev/null
			systemctl start hpshd &> /dev/null
		fi
	
	fi
	  # For upgrading v55 to v56, smx-v55 have the providers SMXSmartArray and SMXSCSI they are not	
		# support by hardware, so we comment out the code of the providers in v56 and remove the modules SMXSmartArrayModule
		# SMXBaseSCSIHBAModule.
		for module in `cimprovider -l | grep SMX`; do
			if [ "$module" = "SMXSmartArrayModule" ]; then
				cimprovider -rm $module > /dev/null 2>&1
			fi

			if [ "$module" = "SMXBaseSCSIHBAModule" ]; then
				cimprovider -rm $module > /dev/null 2>&1
			fi
		done

}

uninstall_rpm() {
        # make sure the tog-pegasus is started.
        # we started the tog-pegasus before call this function.    
	if [ -f /etc/init.d/tog-pegasus  ] ; then
            /etc/init.d/tog-pegasus status &> /dev/null
        else
            systemctl status tog-pegasus.service &> /dev/null
        fi           

        if [[ $? != 0 ]]; then
            # it's not good to give error here.
            # but better later than nothing.
            echo "Failed to start tog-pegasus."
            # Stop here, the steps need a running pegasus.
            return 1
        fi

	/opt/hp/hp-smx/bin/rmsubs -y
        
	# Uninstall SMX schema in root/interop namespace
	echo "Uninstalling SMX schema in root/interop." 
        for class in `cat $PREFIX/mof/moflist-reversed.root\#interop`; do
        	$PREFIX/bin/deleteclass.sh -n root/interop $class
	done	

	# Uninstall SMX schema in root/cimv2 namespace
	echo "Uninstalling SMX schema in root/cimv2." 
        for class in `cat $PREFIX/mof/moflist-reversed.root\#cimv2`; do
        	$PREFIX/bin/deleteclass.sh -n root/cimv2 $class
	done
	
        # Remove providers.
        echo "Uninstalling SMX provider."
        for module in `cat $PREFIX/reg/*modulelist |grep -v SMXExecutiveModule |grep -v grep`; do
              cimprovider -rm $module > /dev/null 2>&1
	done
              cimprovider -rm SMXExecutiveModule > /dev/null 2>&1

        # Stop tog-pegasus and remove the repository for root/hpq
	if [ -f /etc/init.d/tog-pegasus  ]; then
            /etc/init.d/tog-pegasus stop &> /dev/null
            sleep 3
            /etc/init.d/tog-pegasus status &> /dev/null
        else
            systemctl stop tog-pegasus.service &> /dev/null
            sleep 3
            systemctl status tog-pegasus.service &> /dev/null
        fi           
        if [ $? != 3 ]; then
            echo "Failed to stop tog-pegasus."
            return 1
        fi
        
        echo "Removing SMX repository."
        rm -rf /var/lib/Pegasus/repository/root#hpq
        rm -rf /var/log/SMX-*.log


	if [ -f /etc/init.d/tog-pegasus  ] ; then
            /etc/init.d/tog-pegasus start &> /dev/null
            sleep 3
            /etc/init.d/tog-pegasus status &> /dev/null
        else
            systemctl start tog-pegasus.service &> /dev/null
            sleep 3
            systemctl status tog-pegasus.service &> /dev/null
        fi           
        if [ $? != 0 ]; then
            echo "Failed to start tog-pegasus."
            return 1
        fi

	for module in `cimprovider -l | grep SMX`; do
		cimprovider -rm $module > /dev/null 2>&1
	done
}

case "$1" in

	install|uninstall)
		$1_rpm
        ;;

	*)
		echo "Usage: $0 {install|uninstall} {base directory}"
		RETVAL=2
        ;;
esac

exit $RETVAL
